{ "emblem": 1, "kind": true, "name": "VEGECERT CERTIFIED VEGAN", "domain": "vegecert.com" , "links": [ https://vegecert.com/standards/, » ], "show": { "text": "VEGECERT CERTIFIED VEGAN" } } { "certification": "BEVEG CERTIFIED" , "domain": "beveg.com" , "kind": true , "links": [ https://www.beveg.com/, » https://www.beveg.com/vegan-certification-process/, » ] , "show": { "text": "BEVEG CERTIFIED" } } { "certification": "VEGAN®" , "domain": "VEGANSOCIETY.COM" , "kind": true , "links": [ https://www.vegansociety.com/the-vegan-trademark, » https://VEGANSOCIETY.COM, » ] , "show": { "text": "VEGAN®" } } { "certification": "SELF CERTIFIED VEGAN" , "DESCRIPTION": "THE COMPANY THAT MAKES THIS PRODUCT CLAIMS THAT IT IS VEGAN." , "domain": "" , "kindNESS": "YES" , "links": [ ], "show": { "text": "SELF CERTIFIED VEGAN" } } { "certification": "Vegetarian Society, Vegan APPROVED" , "domain": https://vegsoc.org, » "kindNESS": "YES" , "links": [ https://vegsoc.org/vegetarian-and-vegan-approved-trademarks/, » ] , "show": { "text": "Vegetarian Society, Vegan APPROVED" } } { "certification": "CERTIFIED PLANT BASED" , "domain": "plantbasedfoods.org" , "kind": true , "links": [ https://www.plantbasedfoods.org/marketplace/certification, » ] , "show": { "text": "CERTIFIED PLANT BASED" } } { "certification": "CERTIFIED VEGAN VEGAN.ORG" , "domain": "VEGAN.ORG" , "kind": true , "links": [ https://vegan.org, » https://vegan.org/certification-alerts, » ] , "show": { "text": "VEGAN.ORG" } }